@@ -12,7 +12,7 @@ class JSONDataSet(JDS):
     """``JSONDataSet`` saves data to a JSON file using an underlying
     filesystem (e.g.: local, S3, GCS). It uses native json to handle the JSON file.
     The ``JSONDataSet`` is part of Kedro Experiment Tracking.
-    The dataset is versioned by default.
+    The dataset is write-only and it is versioned by default.
 
         Example:
         ::
@@ -24,8 +24,6 @@ class JSONDataSet(JDS):
         >>> # data_set = JSONDataSet(filepath="gcs://bucket/test.json")
         >>> data_set = JSONDataSet(filepath="test.json")
         >>> data_set.save(data)
-        >>> reloaded = data_set.load()
-        >>> assert data == reloaded
 
     """
 
