@@ -71,21 +71,26 @@ class KedroSessionError(Exception):
 
 class KedroSession:
     """``KedroSession`` is the object that is responsible for managing the lifecycle
-    of a Kedro run.
-    - Use `KedroSession.create("<your-kedro-project-package-name>")` as
+    of a Kedro run. Use `KedroSession.create("<package_name>")` as
     a context manager to construct a new KedroSession with session data
     provided (see the example below).
-    - Use `KedroSession(session_id=<id>)` to instantiate an existing session with a given
-    ID.
+
+
 
     Example:
     ::
 
         >>> from kedro.framework.session import KedroSession
-        >>>
-        >>> with KedroSession.create("<your-kedro-project-package-name>") as session:
+        >>> from kedro.framework.startup import bootstrap_project
+        >>> from pathlib import Path
+
+        >>> # If you are creating a session outside of a Kedro project (i.e. not using
+        >>> # `kedro run` or `kedro jupyter`), you need to run `bootstrap_project` to
+        >>> # let Kedro find your configuration.
+        >>> metadata = bootstrap_project(Path("<project_root>"))
+        >>> with KedroSession.create(metadata.package_name) as session:
         >>>     session.run()
-        >>>
+
     """
 
     def __init__(
