@@ -28,7 +28,7 @@ VERSIONED_FLAG_KEY = "versioned"
 VERSION_KEY = "version"
 HTTP_PROTOCOLS = ("http", "https")
 PROTOCOL_DELIMITER = "://"
-CLOUD_PROTOCOLS = ("s3", "gcs", "gs", "adl", "abfs", "abfss")
+CLOUD_PROTOCOLS = ("s3", "gcs", "gs", "adl", "abfs", "abfss", "gdrive")
 
 
 class DataSetError(Exception):
